# Volmdlr

A python VOLume MoDeLeR computations-oriented with STEP support for import/export

![badge](https://drone-opensource.dessia.tech/api/badges/Dessia-tech/volmdlr/status.svg?branch=master)
[![Contributors][contributors-shield]][contributors-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]



![casing](https://raw.githubusercontent.com/Dessia-tech/volmdlr/master/doc/source/images/casing.jpg)

## Features

* Generate 3D geometries from python
* Primitives provides computational tasks (distances, belonging, union, intersections...)
* STEP/STL import and exports

## Installing

.. code::

  pip(3) install volmdlr

## Usage

See the script folder for examples

## Documentation
https://volmdlr.readthedocs.io/en/latest/

## Licence

100% opensource on LGPL licence. See LICENCE for more details.

## Contributors

- [DessiA team](https://github.com/orgs/Dessia-tech/people)
- [Mack Joly](https://www.linkedin.com/in/mack-joly-979824182/)


[contributors-shield]: https://img.shields.io/github/contributors/Dessia-tech/volmdlr.svg?style=for-the-badge
[stars-shield]: https://img.shields.io/github/stars/Dessia-tech/volmdlr.svg
[issues-shield]: https://img.shields.io/github/issues/Dessia-tech/volmdlr.svg?style=for-the-badge

[contributors-url]: https://github.com/Dessia-tech/volmdlr/graphs/contributors
[stars-url]: https://github.com/Dessia-tech/volmdlr/stargazers
[issues-url]: https://github.com/Dessia-tech/volmdlr/issues
